# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0]
### Fixed
- Fixed linter warnings

### Added
- Added github workflows

### Changed
- Refactored API to be cleaner
- Consolidated package definition to pyproject.toml only

## [0.1.1]
### Fixed
- Added generation of missing NS records in reverse zones.

## [0.1.0]
### Added
- Basic command line tool for generating zone files.
